'''
This module contains openscad built-in defintions
'''


SCAD_VARS = ['PI', '$fa', '$fs', '$fn', '$t', '$vpr', '$vpt', '$vpd', '$children',
             '$preview']

SCAD_MODS = ['union', 'difference', 'intersection', 'echo', 'render', 'children',
             'assert', 'assign', 'circle', 'square', 'polygon', 'text', 'import',
             'projection', 'sphere', 'cube', 'cylinder', 'polyhedron',
             'linear_extrude', 'rotate_extrude', 'surface', 'translate', 'rotate',
             'scale', 'resize', 'mirror', 'multmatrix', 'color', 'offset', 'hull',
             'minkowski']

SCAD_FUNCS = ['is_undef', 'is_bool', 'is_num', 'is_string', 'is_list', 'concat', 'lookup',
              'str', 'chr', 'ord', 'search', 'version', 'version_num', 'parent_module',
              'abs', 'sign', 'sin', 'cos', 'tan', 'acos', 'asin', 'atan', 'atan2', 'floor',
              'round', 'ceil', 'ln', 'len', 'let', 'log', 'pow', 'sqrt', 'exp', 'rands',
              'min', 'max', 'norm', 'cross']
